// Copyright 2020 Liftoff.
// Licensed under the CC BY-ND 2.0 License: https://creativecommons.org/licenses/by-nd/2.0/

#import <Foundation/Foundation.h>

/*
 * Interface to the Liftoff performance marketing SDK.
 *
 * This class follows the Singleton pattern, so your application should call the
 * sharedInstanceWithApiKey:appId: and sharedInstance methods rather than instantiating this class
 * directly.
 *
 * Sample integration code:
 *
 *     // In your Application delegate:
 *     #import "Liftoff.h"
 *     //...
 *     - (BOOL)application:(UIApplication *)application
 *         didFinishLaunchingWithOptions:(NSDictionary *)launchOptions {
 *       //...
 *       [[Liftoff sharedInstanceWithApiKey:YOUR_LIFTOFF_API_KEY appId:YOUR_LIFTOFF_APP_ID] startSession];
 *     }
 *
 *     // When the user performs some significant action (e.g. signs up for an account):
 *     [[Liftoff sharedInstance] recordEvent:@"signup"];
 *
 * For more detailed integration documentation, please see our online docs referenced in the README.
 */
@interface Liftoff : NSObject

/*
 * Initializes the Liftoff SDK with your Liftoff API key and app ID, and returns the singleton Liftoff class
 * instance.
 *
 * After this is called once, you should use [Liftoff sharedInstance] from then on.
 */
+ (Liftoff *)sharedInstanceWithApiKey:(NSString *)apiKey appId:(NSString *)appId testMode:(BOOL)testMode
NS_SWIFT_NAME(shared(apiKey:appId:testMode:));

/*
 * Returns the singleton Liftoff class instance.
 *
 * You must call sharedInstanceWithApiKey:appId: once before you start calling this method.
 */
+ (Liftoff *)sharedInstance NS_SWIFT_NAME(shared());

/*
 * Records an install event if it's the first time the app is run. This also records a new_session event.
 *
 * Call this every time your app launches, from applicationDidFinishLaunching or
 * application:didFinishLaunchingWithOptions in your Application delegate.
 */
- (void)startSession;

/*
 * Record an application-specific engagement event like "signup", "purchase" or "tutorial_complete".
 *
 * These events will show up in the Liftoff dashboard. We recommend lowercase event names with underscores
 * instead of spaces.
 *
 * You should not use programmatically generated strings (e.g. that are user-specific) as event names; instead
 * use hard-coded strings such as "signup" which describe a general point in your application's user flow.
 * Most developers have 10 or less unique event names per app.
 */
- (void)recordEvent:(NSString *)eventName;

/*
 * Record an engagement event which has a revenue transaction amount associated with it, e.g. a $12.50 in-app
 * purchase.
 * - currencyCode: a 3 letter ISO 4217 currency code, for example: "USD", "GBR", "EUR", "AUD", "CAD", "JPY".
 *   See the Liftoff SDK docs for a full list.
 */
- (void)recordEvent:(NSString *)eventName revenue:(NSNumber *)revenue currencyCode:(NSString *)currencyCode;

@end
